{# def data #}

{% if data %}

    <div class="ui multilingual-tabs">
        <div class="ui compact text menu separated">
            {% for item in data %}
                <a class="green item {{'active' if loop.first else ''}}" data-tab="{{item|id}}-{{item.lang|e}}">{{item.lang|upper}}</a>
                {% if not loop.last %}
                <div class="separator"><div class="vertical-bar"></div></div>
                {% endif %}
            {% endfor %}
        </div>
        {% for item in data %}
        <div class="ui tab {{'active' if loop.first else ''}}" data-tab="{{item|id}}-{{item.lang|e}}">
            {{ item.value }}
        </div>
        {% endfor %}
    </div>
{% endif %}